info = {
    "name": "kw",
    "date_order": "YMD",
    "january": [
        "gen",
        "mis genver"
    ],
    "february": [
        "hwe",
        "mis hwevrer"
    ],
    "march": [
        "meu",
        "mis meurth"
    ],
    "april": [
        "ebr",
        "mis ebrel"
    ],
    "may": [
        "me",
        "mis me"
    ],
    "june": [
        "met",
        "mis metheven"
    ],
    "july": [
        "gor",
        "mis gortheren"
    ],
    "august": [
        "est",
        "mis est"
    ],
    "september": [
        "gwn",
        "mis gwynngala"
    ],
    "october": [
        "hed",
        "mis hedra"
    ],
    "november": [
        "du",
        "mis du"
    ],
    "december": [
        "kev",
        "mis kevardhu"
    ],
    "monday": [
        "dy lun",
        "lun"
    ],
    "tuesday": [
        "dy meurth",
        "mth"
    ],
    "wednesday": [
        "dy merher",
        "mhr"
    ],
    "thursday": [
        "dy yow",
        "yow"
    ],
    "friday": [
        "dy gwener",
        "gwe"
    ],
    "saturday": [
        "dy sadorn",
        "sad"
    ],
    "sunday": [
        "dy sul",
        "sul"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "sah",
    "date_order": "YMD",
    "january": [
        "тохс",
        "тохсунньу"
    ],
    "february": [
        "олун",
        "олунньу"
    ],
    "march": [
        "клн",
        "кулун тутар"
    ],
    "april": [
        "мсу",
        "муус устар"
    ],
    "may": [
        "ыам",
        "ыам ыйа",
        "ыам ыйын"
    ],
    "june": [
        "бэс",
        "бэс ыйа",
        "бэс ыйын"
    ],
    "july": [
        "от ыйа",
        "от ыйын",
        "отй"
    ],
    "august": [
        "атр",
        "атырдьых ыйа",
        "атырдьых ыйын"
    ],
    "september": [
        "балаҕан ыйа",
        "балаҕан ыйын",
        "блҕ"
    ],
    "october": [
        "алт",
        "алтынньы"
    ],
    "november": [
        "сэт",
        "сэтинньи"
    ],
    "december": [
        "ахс",
        "ахсынньы"
    ],
    "monday": [
        "бн",
        "бэнидиэнньик"
    ],
    "tuesday": [
        "оп",
        "оптуорунньук"
    ],
    "wednesday": [
        "сэ",
        "сэрэдэ"
    ],
    "thursday": [
        "чп",
        "чэппиэр"
    ],
    "friday": [
        "бэ",
        "бээтиҥсэ"
    ],
    "saturday": [
        "сб",
        "субуота"
    ],
    "sunday": [
        "баскыһыанньа",
        "бс"
    ],
    "am": [
        "эи"
    ],
    "pm": [
        "эк"
    ],
    "year": [
        "сыл"
    ],
    "month": [
        "ый"
    ],
    "week": [
        "нэдиэлэ"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "чаас"
    ],
    "minute": [
        "мүнүүтэ"
    ],
    "second": [
        "сөкүүндэ"
    ],
    "relative-type": {
        "0 day ago": [
            "бүгүн"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "бу ый"
        ],
        "0 second ago": [
            "билигин"
        ],
        "0 week ago": [
            "бу нэдиэлэ"
        ],
        "0 year ago": [
            "быйыл"
        ],
        "1 day ago": [
            "бэҕэһээ"
        ],
        "1 month ago": [
            "ааспыт ый"
        ],
        "1 week ago": [
            "ааспыт нэдиэлэ"
        ],
        "1 year ago": [
            "былырыын"
        ],
        "in 1 day": [
            "сарсын"
        ],
        "in 1 month": [
            "аныгыскы ый"
        ],
        "in 1 week": [
            "кэлэр нэдиэлэ"
        ],
        "in 1 year": [
            "эһиил"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) күн ынараа өттүгэр"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) чаас ынараа өттүгэр"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) мүнүүтэ ынараа өттүгэр"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ый ынараа өттүгэр"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) сөк анараа өттүгэр",
            "(\\d+[.,]?\\d*) сөкүүндэ ынараа өттүгэр"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) нэдиэлэ анараа өттүгэр"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) сыл ынараа өттүгэр"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) күнүнэн"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) чааһынан"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) мүнүүтэннэн"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ыйынан"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) сөкүүндэннэн"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) нэдиэлэннэн"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) сылынан"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "uz-Latn",
    "date_order": "DMY",
    "january": [
        "yan",
        "yanvar"
    ],
    "february": [
        "fev",
        "fevral"
    ],
    "march": [
        "mar",
        "mart"
    ],
    "april": [
        "apr",
        "aprel"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyn",
        "iyun"
    ],
    "july": [
        "iyl",
        "iyul"
    ],
    "august": [
        "avg",
        "avgust"
    ],
    "september": [
        "sen",
        "sentabr"
    ],
    "october": [
        "okt",
        "oktabr"
    ],
    "november": [
        "noy",
        "noyabr"
    ],
    "december": [
        "dek",
        "dekabr"
    ],
    "monday": [
        "dush",
        "dushanba"
    ],
    "tuesday": [
        "sesh",
        "seshanba"
    ],
    "wednesday": [
        "chor",
        "chorshanba"
    ],
    "thursday": [
        "pay",
        "payshanba"
    ],
    "friday": [
        "jum",
        "juma"
    ],
    "saturday": [
        "shan",
        "shanba"
    ],
    "sunday": [
        "yak",
        "yakshanba"
    ],
    "am": [
        "to"
    ],
    "pm": [
        "tk"
    ],
    "year": [
        "yil"
    ],
    "month": [
        "oy"
    ],
    "week": [
        "hafta"
    ],
    "day": [
        "kun"
    ],
    "hour": [
        "soat"
    ],
    "minute": [
        "daq",
        "daqiqa"
    ],
    "second": [
        "son",
        "soniya"
    ],
    "relative-type": {
        "0 day ago": [
            "bugun"
        ],
        "0 hour ago": [
            "shu soatda"
        ],
        "0 minute ago": [
            "shu daqiqada"
        ],
        "0 month ago": [
            "shu oy"
        ],
        "0 second ago": [
            "hozir"
        ],
        "0 week ago": [
            "shu hafta"
        ],
        "0 year ago": [
            "bu yil",
            "shu yil"
        ],
        "1 day ago": [
            "kecha"
        ],
        "1 month ago": [
            "o‘tgan oy"
        ],
        "1 week ago": [
            "o‘tgan hafta"
        ],
        "1 year ago": [
            "o'tgan yil",
            "o‘tgan yil"
        ],
        "in 1 day": [
            "ertaga"
        ],
        "in 1 month": [
            "keyingi oy"
        ],
        "in 1 week": [
            "keyingi hafta"
        ],
        "in 1 year": [
            "keyingi yil"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) kun oldin"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) soat oldin"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) daqiqa oldin"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) oy oldin"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) soniya oldin"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) hafta oldin"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) yil oldin"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) kundan keyin"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) soatdan keyin"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) daqiqadan keyin"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) oydan keyin"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) soniyadan keyin"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) haftadan keyin"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) yildan keyin"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "fa",
    "date_order": "YMD",
    "january": [
        "ژانویه",
        "ژانویهٔ",
        "جنوری"
    ],
    "february": [
        "فوریه",
        "فوریهٔ",
        "فبروری"
    ],
    "march": [
        "مارس",
        "مارچ"
    ],
    "april": [
        "آوریل",
        "اپریل"
    ],
    "may": [
        "مه",
        "مهٔ",
        "می"
    ],
    "june": [
        "ژوئن",
        "جون"
    ],
    "july": [
        "ژوئیه",
        "ژوئیهٔ",
        "جولای"
    ],
    "august": [
        "اوت",
        "آگست"
    ],
    "september": [
        "سپتامبر",
        "سپتمبر"
    ],
    "october": [
        "اکتبر",
        "اکتوبر"
    ],
    "november": [
        "نوامبر",
        "نومبر"
    ],
    "december": [
        "دسامبر",
        "دسمبر"
    ],
    "monday": [
        "دوشنبه"
    ],
    "tuesday": [
        "سه‌شنبه",
        "سهشنبه"
    ],
    "wednesday": [
        "چهارشنبه",
        "چهار شنبه"
    ],
    "thursday": [
        "پنجشنبه",
        "پنج شنبه"
    ],
    "friday": [
        "جمعه"
    ],
    "saturday": [
        "شنبه",
        "روز شنبه",
        "دو شنبه",
        "د"
    ],
    "sunday": [
        "یکشنبه"
    ],
    "am": [
        "قبل‌ازظهر",
        "قظ"
    ],
    "pm": [
        "بظ",
        "بعدازظهر"
    ],
    "year": [
        "سال"
    ],
    "month": [
        "ماه"
    ],
    "week": [
        "هفته"
    ],
    "day": [
        "روز"
    ],
    "hour": [
        "ساعت"
    ],
    "minute": [
        "دقیقه"
    ],
    "second": [
        "ثانیه",
        "دوم"
    ],
    "relative-type": {
        "0 day ago": [
            "امروز"
        ],
        "0 hour ago": [
            "همین ساعت"
        ],
        "0 minute ago": [
            "همین دقیقه"
        ],
        "0 month ago": [
            "این ماه"
        ],
        "0 second ago": [
            "اکنون"
        ],
        "0 week ago": [
            "این هفته"
        ],
        "0 year ago": [
            "امسال"
        ],
        "1 day ago": [
            "دیروز"
        ],
        "1 month ago": [
            "ماه پیش",
            "ماه گذشته"
        ],
        "1 week ago": [
            "هفتهٔ گذشته"
        ],
        "1 year ago": [
            "سال گذشته"
        ],
        "in 1 day": [
            "فردا"
        ],
        "in 1 month": [
            "ماه آینده"
        ],
        "in 1 week": [
            "هفتهٔ آینده"
        ],
        "in 1 year": [
            "سال آینده"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) روز پیش"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) ساعت پیش"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) دقیقه پیش"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ماه پیش"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) ثانیه پیش"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) هفته پیش"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) سال پیش"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) روز بعد"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) ساعت بعد"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) دقیقه بعد"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ماه بعد"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) ثانیه بعد"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) هفته بعد"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) سال بعد"
        ]
    },
    "locale_specific": {
        "fa-AF": {
            "name": "fa-AF",
            "january": [
                "جنو",
                "جنوری"
            ],
            "february": [
                "فبروری"
            ],
            "march": [
                "مارچ"
            ],
            "april": [
                "اپریل"
            ],
            "may": [
                "می"
            ],
            "june": [
                "جون"
            ],
            "july": [
                "جول",
                "جولای"
            ],
            "august": [
                "اگست"
            ],
            "september": [
                "سپتمبر"
            ],
            "october": [
                "اکتوبر"
            ],
            "november": [
                "نومبر"
            ],
            "december": [
                "دسم",
                "دسمبر"
            ]
        }
    },
    "sentence_splitter_group": 6,
    "ago": [
        "پیش"
    ],
    "in": [
        "در"
    ],
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "dua",
    "date_order": "DMY",
    "january": [
        "di",
        "dimɔ́di"
    ],
    "february": [
        "ŋgɔn",
        "ŋgɔndɛ"
    ],
    "march": [
        "sɔŋ",
        "sɔŋɛ"
    ],
    "april": [
        "diɓ",
        "diɓáɓá"
    ],
    "may": [
        "emi",
        "emiasele"
    ],
    "june": [
        "esɔ",
        "esɔpɛsɔpɛ"
    ],
    "july": [
        "mad",
        "madiɓɛ́díɓɛ́"
    ],
    "august": [
        "diŋ",
        "diŋgindi"
    ],
    "september": [
        "nyɛt",
        "nyɛtɛki"
    ],
    "october": [
        "may",
        "mayésɛ́"
    ],
    "november": [
        "tin",
        "tiníní"
    ],
    "december": [
        "elá",
        "eláŋgɛ́"
    ],
    "monday": [
        "mɔ́s",
        "mɔ́sú"
    ],
    "tuesday": [
        "kwa",
        "kwasú"
    ],
    "wednesday": [
        "muk",
        "mukɔ́sú"
    ],
    "thursday": [
        "ŋgi",
        "ŋgisú"
    ],
    "friday": [
        "ɗón",
        "ɗónɛsú"
    ],
    "saturday": [
        "esa",
        "esaɓasú"
    ],
    "sunday": [
        "ét",
        "éti"
    ],
    "am": [
        "idiɓa"
    ],
    "pm": [
        "ebyámu"
    ],
    "year": [
        "mbú"
    ],
    "month": [
        "mɔ́di"
    ],
    "week": [
        "disama"
    ],
    "day": [
        "búnyá"
    ],
    "hour": [
        "ŋgandɛ"
    ],
    "minute": [
        "ndɔkɔ"
    ],
    "second": [
        "píndí"
    ],
    "relative-type": {
        "0 day ago": [
            "wɛ́ŋgɛ̄"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "kíɛlɛ nítómb́í"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kíɛlɛ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "gsw",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar"
    ],
    "february": [
        "feb",
        "februar"
    ],
    "march": [
        "mär",
        "märz"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "juli"
    ],
    "august": [
        "aug",
        "auguscht"
    ],
    "september": [
        "sep",
        "septämber"
    ],
    "october": [
        "okt",
        "oktoober"
    ],
    "november": [
        "nov",
        "novämber"
    ],
    "december": [
        "dez",
        "dezämber"
    ],
    "monday": [
        "mä",
        "määntig"
    ],
    "tuesday": [
        "zi",
        "ziischtig"
    ],
    "wednesday": [
        "mi",
        "mittwuch"
    ],
    "thursday": [
        "du",
        "dunschtig"
    ],
    "friday": [
        "fr",
        "friitig"
    ],
    "saturday": [
        "sa",
        "samschtig"
    ],
    "sunday": [
        "su",
        "sunntig"
    ],
    "am": [
        "am vormittag",
        "vorm",
        "vormittag"
    ],
    "pm": [
        "am namittag",
        "nam",
        "namittag"
    ],
    "year": [
        "jaar"
    ],
    "month": [
        "monet"
    ],
    "week": [
        "wuche"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "schtund"
    ],
    "minute": [
        "minuute"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "hüt"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "geschter"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "moorn"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "gsw-FR": {
            "name": "gsw-FR"
        },
        "gsw-LI": {
            "name": "gsw-LI"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "hy",
    "date_order": "DMY",
    "january": [
        "հնվ",
        "հունվար",
        "հունվարի"
    ],
    "february": [
        "փետրվար",
        "փետրվարի",
        "փտվ"
    ],
    "march": [
        "մարտ",
        "մարտի",
        "մրտ"
    ],
    "april": [
        "ապր",
        "ապրիլ",
        "ապրիլի"
    ],
    "may": [
        "մայիս",
        "մայիսի",
        "մյս"
    ],
    "june": [
        "հնս",
        "հունիս",
        "հունիսի"
    ],
    "july": [
        "հլս",
        "հուլիս",
        "հուլիսի"
    ],
    "august": [
        "օգոստոս",
        "օգոստոսի",
        "օգս"
    ],
    "september": [
        "սեպ",
        "սեպտեմբեր",
        "սեպտեմբերի"
    ],
    "october": [
        "հոկ",
        "հոկտեմբեր",
        "հոկտեմբերի"
    ],
    "november": [
        "նոյ",
        "նոյեմբեր",
        "նոյեմբերի"
    ],
    "december": [
        "դեկ",
        "դեկտեմբեր",
        "դեկտեմբերի"
    ],
    "monday": [
        "երկ",
        "երկուշաբթի"
    ],
    "tuesday": [
        "երեքշաբթի",
        "երք"
    ],
    "wednesday": [
        "չորեքշաբթի",
        "չրք"
    ],
    "thursday": [
        "հինգշաբթի",
        "հնգ"
    ],
    "friday": [
        "ուր",
        "ուրբաթ"
    ],
    "saturday": [
        "շաբաթ",
        "շբթ"
    ],
    "sunday": [
        "կիր",
        "կիրակի"
    ],
    "am": [
        "am",
        "կա"
    ],
    "pm": [
        "pm",
        "կհ"
    ],
    "year": [
        "տ",
        "տարի"
    ],
    "month": [
        "ամիս",
        "ամս"
    ],
    "week": [
        "շաբ",
        "շաբաթ"
    ],
    "day": [
        "օր"
    ],
    "hour": [
        "ժ",
        "ժամ"
    ],
    "minute": [
        "ր",
        "րոպե"
    ],
    "second": [
        "վ",
        "վայրկյան"
    ],
    "relative-type": {
        "0 day ago": [
            "այսօր"
        ],
        "0 hour ago": [
            "այս ժամին"
        ],
        "0 minute ago": [
            "այս րոպեին"
        ],
        "0 month ago": [
            "այս ամիս"
        ],
        "0 second ago": [
            "այժմ"
        ],
        "0 week ago": [
            "այս շաբաթ"
        ],
        "0 year ago": [
            "այս տարի"
        ],
        "1 day ago": [
            "երեկ"
        ],
        "1 month ago": [
            "անցյալ ամիս",
            "նախորդ ամիս"
        ],
        "1 week ago": [
            "նախորդ շաբաթ"
        ],
        "1 year ago": [
            "նախորդ տարի"
        ],
        "in 1 day": [
            "վաղը"
        ],
        "in 1 month": [
            "հաջորդ ամիս"
        ],
        "in 1 week": [
            "հաջորդ շաբաթ"
        ],
        "in 1 year": [
            "հաջորդ տարի"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) օր առաջ"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) ժ առաջ",
            "(\\d+[.,]?\\d*) ժամ առաջ"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) ր առաջ",
            "(\\d+[.,]?\\d*) րոպե առաջ"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ամիս առաջ"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) վ առաջ",
            "(\\d+[.,]?\\d*) վայրկյան առաջ",
            "(\\d+[.,]?\\d*) վրկ առաջ"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) շաբ առաջ",
            "(\\d+[.,]?\\d*) շաբաթ առաջ"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) տ առաջ",
            "(\\d+[.,]?\\d*) տարի առաջ"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) օրից"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) ժ-ից",
            "(\\d+[.,]?\\d*) ժամից"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) ր-ից",
            "(\\d+[.,]?\\d*) րոպեից"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ամսից"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) վ-ից",
            "(\\d+[.,]?\\d*) վայրկյանից",
            "(\\d+[.,]?\\d*) վրկ-ից"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) շաբ անց",
            "(\\d+[.,]?\\d*) շաբ-ից",
            "(\\d+[.,]?\\d*) շաբաթից"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) տարուց"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "mas",
    "date_order": "DMY",
    "january": [
        "dal",
        "oladalʉ́"
    ],
    "february": [
        "ará",
        "arát"
    ],
    "march": [
        "ɔɛn",
        "ɔɛnɨ́ɔɨŋɔk"
    ],
    "april": [
        "doy",
        "olodoyíóríê inkókúâ"
    ],
    "may": [
        "lép",
        "oloilépūnyīē inkókúâ"
    ],
    "june": [
        "kújúɔrɔk",
        "rok"
    ],
    "july": [
        "mórusásin",
        "sás"
    ],
    "august": [
        "bɔ́r",
        "ɔlɔ́ɨ́bɔ́rárɛ"
    ],
    "september": [
        "kús",
        "kúshîn"
    ],
    "october": [
        "gís",
        "olgísan"
    ],
    "november": [
        "pʉshʉ́ka",
        "shʉ́"
    ],
    "december": [
        "ntʉ́",
        "ntʉ́ŋʉ́s"
    ],
    "monday": [
        "jtt",
        "jumatátu"
    ],
    "tuesday": [
        "jnn",
        "jumane"
    ],
    "wednesday": [
        "jtn",
        "jumatánɔ"
    ],
    "thursday": [
        "alaámisi",
        "alh"
    ],
    "friday": [
        "iju",
        "jumáa"
    ],
    "saturday": [
        "jmo",
        "jumamósi"
    ],
    "sunday": [
        "jpi",
        "jumapílí"
    ],
    "am": [
        "ɛnkakɛnyá"
    ],
    "pm": [
        "ɛndámâ"
    ],
    "year": [
        "ɔlárì"
    ],
    "month": [
        "ɔlápà"
    ],
    "week": [
        "ewíkî"
    ],
    "day": [
        "ɛnkɔlɔ́ŋ"
    ],
    "hour": [
        "ɛ́sáâ"
    ],
    "minute": [
        "oldákikaè"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "táatá"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ŋolé"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tááisérè"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "mas-TZ": {
            "name": "mas-TZ"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



from collections import OrderedDict
from importlib import import_module
from itertools import zip_longest
import regex as re
from copy import deepcopy

from ..data import language_order, language_locale_dict
from .locale import Locale

LOCALE_SPLIT_PATTERN = re.compile(r'-(?=[A-Z0-9]+$)')


def _isvalidlocale(locale):
    language = LOCALE_SPLIT_PATTERN.split(locale)[0]
    if language not in language_order:
        return False
    else:
        locales_list = language_locale_dict[language]
        if locale == language or locale in locales_list:
            return True
        else:
            return False


def _filter_valid_locales(locales):
    return [locale for locale in locales if _isvalidlocale(locale)]


def _construct_locales(languages, region):
    if region:
        possible_locales = [language + '-' + region for language in languages]
        locales = _filter_valid_locales(possible_locales)
    else:
        locales = languages
    return locales


class LocaleDataLoader:
    """Class that handles loading of locale instances."""

    _loaded_languages = {}
    _loaded_locales = {}

    def get_locale_map(self, languages=None, locales=None, region=None,
                       use_given_order=False, allow_conflicting_locales=False):
        """
        Get an ordered mapping with locale codes as keys
        and corresponding locale instances as values.

        :param languages:
            A list of language codes, e.g. ['en', 'es', 'zh-Hant'].
            If locales are not given, languages and region are
            used to construct locales to load.
        :type languages: list

        :param locales:
            A list of codes of locales which are to be loaded,
            e.g. ['fr-PF', 'qu-EC', 'af-NA']
        :type locales: list

        :param region:
            A region code, e.g. 'IN', '001', 'NE'.
            If locales are not given, languages and region are
            used to construct locales to load.
        :type region: str

        :param use_given_order:
            If True, the returned mapping is ordered in the order locales are given.
        :type use_given_order: bool

        :param allow_conflicting_locales:
            if True, locales with same language and different region can be loaded.
        :type allow_conflicting_locales: bool

        :return: ordered locale code to locale instance mapping
        """
        return OrderedDict(self._load_data(
            languages=languages, locales=locales, region=region, use_given_order=use_given_order,
            allow_conflicting_locales=allow_conflicting_locales))

    def get_locales(self, languages=None, locales=None, region=None,
                    use_given_order=False, allow_conflicting_locales=False):
        """
        Yield locale instances.

        :param languages:
            A list of language codes, e.g. ['en', 'es', 'zh-Hant'].
            If locales are not given, languages and region are
            used to construct locales to load.
        :type languages: list

        :param locales:
            A list of codes of locales which are to be loaded,
            e.g. ['fr-PF', 'qu-EC', 'af-NA']
        :type locales: list

        :param region:
            A region code, e.g. 'IN', '001', 'NE'.
            If locales are not given, languages and region are
            used to construct locales to load.
        :type region: str

        :param use_given_order:
            If True, the returned mapping is ordered in the order locales are given.
        :type use_given_order: bool

        :param allow_conflicting_locales:
            if True, locales with same language and different region can be loaded.
        :type allow_conflicting_locales: bool

        :yield: locale instances
        """
        for _, locale in self._load_data(
                languages=languages, locales=locales, region=region,
                use_given_order=use_given_order,
                allow_conflicting_locales=allow_conflicting_locales):
            yield locale

    def get_locale(self, shortname):
        """
        Get a locale instance.

        :param shortname:
            A locale code, e.g. 'fr-PF', 'qu-EC', 'af-NA'.
        :type shortname: str

        :return: locale instance
        """
        return list(self.get_locales(locales=[shortname]))[0]

    def _load_data(self, languages=None, locales=None, region=None,
                   use_given_order=False, allow_conflicting_locales=False):
        locale_dict = OrderedDict()
        if locales:
            invalid_locales = []
            for locale in locales:
                lang_reg = LOCALE_SPLIT_PATTERN.split(locale)
                if len(lang_reg) == 1:
                    lang_reg.append('')
                locale_dict[locale] = tuple(lang_reg)
                if not _isvalidlocale(locale):
                    invalid_locales.append(locale)
            if invalid_locales:
                raise ValueError("Unknown locale(s): %s"
                                 % ', '.join(map(repr, invalid_locales)))

            if not allow_conflicting_locales:
                if len(set(locales)) > len({t[0] for t in locale_dict.values()}):
                    raise ValueError("Locales should not have same language and different region")

        else:
            if languages is None:
                languages = language_order
            unsupported_languages = set(languages) - set(language_order)
            if unsupported_languages:
                raise ValueError("Unknown language(s): %s"
                                 % ', '.join(map(repr, unsupported_languages)))
            if region is None:
                region = ''
            locales = _construct_locales(languages, region)
            locale_dict.update(zip_longest(locales,
                               tuple(zip_longest(languages, [], fillvalue=region))))

        if not use_given_order:
            locale_dict = OrderedDict(sorted(locale_dict.items(),
                                      key=lambda x: language_order.index(x[1][0])))

        for shortname, lang_reg in locale_dict.items():
            if shortname not in self._loaded_locales:
                lang, reg = lang_reg
                if lang in self._loaded_languages:
                    locale = Locale(shortname, language_info=deepcopy(self._loaded_languages[lang]))
                    self._loaded_locales[shortname] = locale
                else:
                    language_info = getattr(
                        import_module('dateparser.data.date_translation_data.' + lang), 'info')
                    locale = Locale(shortname, language_info=deepcopy(language_info))
                    self._loaded_languages[lang] = language_info
                    self._loaded_locales[shortname] = locale
            yield shortname, self._loaded_locales[shortname]


default_loader = LocaleDataLoader()



info = {
    "name": "shi-Latn",
    "date_order": "DMY",
    "january": [
        "inn",
        "innayr"
    ],
    "february": [
        "bṛa",
        "bṛayṛ"
    ],
    "march": [
        "maṛ",
        "maṛṣ"
    ],
    "april": [
        "ibr",
        "ibrir"
    ],
    "may": [
        "may",
        "mayyu"
    ],
    "june": [
        "yun",
        "yunyu"
    ],
    "july": [
        "yul",
        "yulyuz"
    ],
    "august": [
        "ɣuc",
        "ɣuct"
    ],
    "september": [
        "cut",
        "cutanbir"
    ],
    "october": [
        "ktu",
        "ktubr"
    ],
    "november": [
        "nuw",
        "nuwanbir"
    ],
    "december": [
        "duj",
        "dujanbir"
    ],
    "monday": [
        "ayn",
        "aynas"
    ],
    "tuesday": [
        "asi",
        "asinas"
    ],
    "wednesday": [
        "akṛ",
        "akṛas"
    ],
    "thursday": [
        "akw",
        "akwas"
    ],
    "friday": [
        "asim",
        "asimwas"
    ],
    "saturday": [
        "asiḍ",
        "asiḍyas"
    ],
    "sunday": [
        "asa",
        "asamas"
    ],
    "am": [
        "tifawt"
    ],
    "pm": [
        "tadggʷat"
    ],
    "year": [
        "asggʷas"
    ],
    "month": [
        "ayyur"
    ],
    "week": [
        "imalass"
    ],
    "day": [
        "ass"
    ],
    "hour": [
        "tasragt"
    ],
    "minute": [
        "tusdidt"
    ],
    "second": [
        "tasint"
    ],
    "relative-type": {
        "0 day ago": [
            "assa"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "iḍlli"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "askka"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "zu",
    "date_order": "MDY",
    "january": [
        "jan",
        "januwari",
        "umasingana"
    ],
    "february": [
        "feb",
        "februwari"
    ],
    "march": [
        "mas",
        "mashi"
    ],
    "april": [
        "eph",
        "ephreli"
    ],
    "may": [
        "mey",
        "meyi"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "julayi"
    ],
    "august": [
        "aga",
        "agasti"
    ],
    "september": [
        "sep",
        "septhemba"
    ],
    "october": [
        "okt",
        "okthoba"
    ],
    "november": [
        "nov",
        "novemba"
    ],
    "december": [
        "dis",
        "disemba"
    ],
    "monday": [
        "mso",
        "umsombuluko"
    ],
    "tuesday": [
        "bil",
        "ulwesibili"
    ],
    "wednesday": [
        "tha",
        "ulwesithathu"
    ],
    "thursday": [
        "sin",
        "ulwesine"
    ],
    "friday": [
        "hla",
        "ulwesihlanu"
    ],
    "saturday": [
        "mgq",
        "umgqibelo"
    ],
    "sunday": [
        "isonto",
        "son"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "unyaka"
    ],
    "month": [
        "inyanga"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "usuku"
    ],
    "hour": [
        "ihora"
    ],
    "minute": [
        "iminithi"
    ],
    "second": [
        "isekhondi"
    ],
    "relative-type": {
        "0 day ago": [
            "namhlanje"
        ],
        "0 hour ago": [
            "leli hora"
        ],
        "0 minute ago": [
            "leli minithi"
        ],
        "0 month ago": [
            "le nyanga"
        ],
        "0 second ago": [
            "manje"
        ],
        "0 week ago": [
            "leli viki"
        ],
        "0 year ago": [
            "kulo nyaka"
        ],
        "1 day ago": [
            "izolo"
        ],
        "1 month ago": [
            "inyanga edlule"
        ],
        "1 week ago": [
            "iviki eledlule"
        ],
        "1 year ago": [
            "onyakeni odlule"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "in 1 month": [
            "inyanga ezayo"
        ],
        "in 1 week": [
            "iviki elizayo"
        ],
        "in 1 year": [
            "unyaka ozayo"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) izinsuku ezedlule",
            "(\\d+[.,]?\\d*) usuku olwedlule"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) amahora edlule",
            "(\\d+[.,]?\\d*) ihora eledlule"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) amaminithi edlule",
            "(\\d+[.,]?\\d*) iminithi eledlule"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) inyanga edlule",
            "(\\d+[.,]?\\d*) izinyanga ezedlule"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) amasekhondi edlule",
            "(\\d+[.,]?\\d*) isekhondi eledlule"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) iminyaka edlule",
            "(\\d+[.,]?\\d*) unyaka odlule"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "haw",
    "date_order": "DMY",
    "january": [
        "ian",
        "ianuali"
    ],
    "february": [
        "pep",
        "pepeluali"
    ],
    "march": [
        "mal",
        "malaki"
    ],
    "april": [
        "'ap",
        "'apelila"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "iun",
        "iune"
    ],
    "july": [
        "iul",
        "iulai"
    ],
    "august": [
        "'au",
        "'aukake"
    ],
    "september": [
        "kep",
        "kepakemapa"
    ],
    "october": [
        "'ok",
        "'okakopa"
    ],
    "november": [
        "now",
        "nowemapa"
    ],
    "december": [
        "kek",
        "kekemapa"
    ],
    "monday": [
        "p1",
        "po'akahi"
    ],
    "tuesday": [
        "p2",
        "po'alua"
    ],
    "wednesday": [
        "p3",
        "po'akolu"
    ],
    "thursday": [
        "p4",
        "po'ahā"
    ],
    "friday": [
        "p5",
        "po'alima"
    ],
    "saturday": [
        "p6",
        "po'aono"
    ],
    "sunday": [
        "lp",
        "lāpule"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "sq",
    "date_order": "DMY",
    "january": [
        "jan",
        "janar"
    ],
    "february": [
        "shk",
        "shkurt"
    ],
    "march": [
        "mar",
        "mars"
    ],
    "april": [
        "pri",
        "prill"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "qer",
        "qershor"
    ],
    "july": [
        "kor",
        "korrik"
    ],
    "august": [
        "gsh",
        "gusht"
    ],
    "september": [
        "sht",
        "shtator"
    ],
    "october": [
        "tet",
        "tetor"
    ],
    "november": [
        "nën",
        "nëntor"
    ],
    "december": [
        "dhj",
        "dhjetor"
    ],
    "monday": [
        "e hënë",
        "hën"
    ],
    "tuesday": [
        "e martë",
        "mar"
    ],
    "wednesday": [
        "e mërkurë",
        "mër"
    ],
    "thursday": [
        "e enjte",
        "enj"
    ],
    "friday": [
        "e premte",
        "pre"
    ],
    "saturday": [
        "e shtunë",
        "sht"
    ],
    "sunday": [
        "die",
        "e diel"
    ],
    "am": [
        "e paradites",
        "paradite"
    ],
    "pm": [
        "e pasdites",
        "pasdite"
    ],
    "year": [
        "vit"
    ],
    "month": [
        "muaj"
    ],
    "week": [
        "javë"
    ],
    "day": [
        "ditë"
    ],
    "hour": [
        "orë"
    ],
    "minute": [
        "min",
        "minutë"
    ],
    "second": [
        "sek",
        "sekondë"
    ],
    "relative-type": {
        "0 day ago": [
            "sot"
        ],
        "0 hour ago": [
            "këtë orë"
        ],
        "0 minute ago": [
            "këtë minutë"
        ],
        "0 month ago": [
            "këtë muaj"
        ],
        "0 second ago": [
            "tani"
        ],
        "0 week ago": [
            "këtë javë"
        ],
        "0 year ago": [
            "këtë vit"
        ],
        "1 day ago": [
            "dje"
        ],
        "1 month ago": [
            "muajin e kaluar"
        ],
        "1 week ago": [
            "javën e kaluar"
        ],
        "1 year ago": [
            "vitin e kaluar"
        ],
        "in 1 day": [
            "nesër"
        ],
        "in 1 month": [
            "muajin e ardhshëm"
        ],
        "in 1 week": [
            "javën e ardhshme"
        ],
        "in 1 year": [
            "vitin e ardhshëm"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) ditë më parë"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) orë më parë"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) min më parë",
            "(\\d+[.,]?\\d*) minuta më parë",
            "(\\d+[.,]?\\d*) minutë më parë"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) muaj më parë"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) sek më parë",
            "(\\d+[.,]?\\d*) sekonda më parë",
            "(\\d+[.,]?\\d*) sekondë më parë"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) javë më parë"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) vit më parë",
            "(\\d+[.,]?\\d*) vjet më parë"
        ],
        "in \\1 day": [
            "pas (\\d+[.,]?\\d*) dite",
            "pas (\\d+[.,]?\\d*) ditësh"
        ],
        "in \\1 hour": [
            "pas (\\d+[.,]?\\d*) ore",
            "pas (\\d+[.,]?\\d*) orësh"
        ],
        "in \\1 minute": [
            "pas (\\d+[.,]?\\d*) min",
            "pas (\\d+[.,]?\\d*) minutash",
            "pas (\\d+[.,]?\\d*) minute"
        ],
        "in \\1 month": [
            "pas (\\d+[.,]?\\d*) muaji",
            "pas (\\d+[.,]?\\d*) muajsh"
        ],
        "in \\1 second": [
            "pas (\\d+[.,]?\\d*) sek",
            "pas (\\d+[.,]?\\d*) sekondash",
            "pas (\\d+[.,]?\\d*) sekonde"
        ],
        "in \\1 week": [
            "pas (\\d+[.,]?\\d*) jave",
            "pas (\\d+[.,]?\\d*) javësh"
        ],
        "in \\1 year": [
            "pas (\\d+[.,]?\\d*) viti",
            "pas (\\d+[.,]?\\d*) vjetësh"
        ]
    },
    "locale_specific": {
        "sq-MK": {
            "name": "sq-MK"
        },
        "sq-XK": {
            "name": "sq-XK"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "ky",
    "date_order": "DMY",
    "january": [
        "янв",
        "январь"
    ],
    "february": [
        "фев",
        "февраль"
    ],
    "march": [
        "мар",
        "март"
    ],
    "april": [
        "апр",
        "апрель"
    ],
    "may": [
        "май"
    ],
    "june": [
        "июн",
        "июнь"
    ],
    "july": [
        "июл",
        "июль"
    ],
    "august": [
        "авг",
        "август"
    ],
    "september": [
        "сен",
        "сентябрь"
    ],
    "october": [
        "окт",
        "октябрь"
    ],
    "november": [
        "ноя",
        "ноябрь"
    ],
    "december": [
        "дек",
        "декабрь"
    ],
    "monday": [
        "дүй",
        "дүйшөмбү"
    ],
    "tuesday": [
        "шейш",
        "шейшемби"
    ],
    "wednesday": [
        "шарш",
        "шаршемби"
    ],
    "thursday": [
        "бейш",
        "бейшемби"
    ],
    "friday": [
        "жума"
    ],
    "saturday": [
        "ишемби",
        "ишм"
    ],
    "sunday": [
        "жек",
        "жекшемби"
    ],
    "am": [
        "таңкы",
        "тң"
    ],
    "pm": [
        "тк",
        "түштөн кийинки"
    ],
    "year": [
        "ж",
        "жыл"
    ],
    "month": [
        "ай"
    ],
    "week": [
        "апт",
        "апта"
    ],
    "day": [
        "күн"
    ],
    "hour": [
        "саат",
        "ст"
    ],
    "minute": [
        "м",
        "мүн",
        "мүнөт"
    ],
    "second": [
        "сек",
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "бүгүн"
        ],
        "0 hour ago": [
            "ушул саатта"
        ],
        "0 minute ago": [
            "ушул мүнөттө"
        ],
        "0 month ago": [
            "бул айда"
        ],
        "0 second ago": [
            "азыр"
        ],
        "0 week ago": [
            "ушул апт",
            "ушул аптада"
        ],
        "0 year ago": [
            "быйыл"
        ],
        "1 day ago": [
            "кечээ"
        ],
        "1 month ago": [
            "өткөн айда"
        ],
        "1 week ago": [
            "өткөн апт",
            "өткөн аптада"
        ],
        "1 year ago": [
            "былтыр"
        ],
        "in 1 day": [
            "эртеӊ"
        ],
        "in 1 month": [
            "эмдиги айда"
        ],
        "in 1 week": [
            "келерки апт",
            "келерки аптада"
        ],
        "in 1 year": [
            "эмдиги жылы"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) күн мурун"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) с мурн",
            "(\\d+[.,]?\\d*) саат мурун"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) мүн мурн",
            "(\\d+[.,]?\\d*) мүн мурун",
            "(\\d+[.,]?\\d*) мүнөт мурун"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ай мурн",
            "(\\d+[.,]?\\d*) ай мурун"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) сек мурн",
            "(\\d+[.,]?\\d*) сек мурун",
            "(\\d+[.,]?\\d*) секунд мурун"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) апт мурун",
            "(\\d+[.,]?\\d*) апта мурун"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) жыл мурун"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) күн кийин",
            "(\\d+[.,]?\\d*) күндөн кийин"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) с кийн",
            "(\\d+[.,]?\\d*) саат кийин",
            "(\\d+[.,]?\\d*) сааттан кийин"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) мүн кийин",
            "(\\d+[.,]?\\d*) мүн кийн",
            "(\\d+[.,]?\\d*) мүнөттөн кийин"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) айд кийин",
            "(\\d+[.,]?\\d*) айд кийн",
            "(\\d+[.,]?\\d*) айдан кийин"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) сек кийин",
            "(\\d+[.,]?\\d*) сек кийн",
            "(\\d+[.,]?\\d*) секунддан кийин"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) апт кийин",
            "(\\d+[.,]?\\d*) аптадан кийин"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) жыл кийин",
            "(\\d+[.,]?\\d*) жылдан кийин"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "vi",
    "date_order": "DMY",
    "january": [
        "thg 1",
        "tháng 1",
        "Tháng một"
    ],
    "february": [
        "thg 2",
        "tháng 2",
        "Tháng hai"
    ],
    "march": [
        "thg 3",
        "tháng 3",
        "Tháng ba"
    ],
    "april": [
        "thg 4",
        "tháng 4",
        "Tháng tư"
    ],
    "may": [
        "thg 5",
        "tháng 5",
        "Tháng năm"
    ],
    "june": [
        "thg 6",
        "tháng 6",
        "Tháng sáu"
    ],
    "july": [
        "thg 7",
        "tháng 7",
        "Tháng bảy"
    ],
    "august": [
        "thg 8",
        "tháng 8",
        "Tháng tám"
    ],
    "september": [
        "thg 9",
        "tháng 9",
        "Tháng chín"
    ],
    "october": [
        "thg 10",
        "tháng 10",
        "Tháng mười"
    ],
    "november": [
        "thg 11",
        "tháng 11",
        "Tháng mười một"
    ],
    "december": [
        "thg 12",
        "tháng 12",
        "Tháng mười hai"
    ],
    "monday": [
        "th 2",
        "thứ hai",
        "Thứ 2"
    ],
    "tuesday": [
        "th 3",
        "thứ ba",
        "Thứ 3"
    ],
    "wednesday": [
        "th 4",
        "thứ tư",
        "Thứ 4"
    ],
    "thursday": [
        "th 5",
        "thứ năm",
        "Thứ 5"
    ],
    "friday": [
        "th 6",
        "thứ sáu",
        "Thứ 6"
    ],
    "saturday": [
        "th 7",
        "thứ bảy",
        "Thứ 7"
    ],
    "sunday": [
        "chủ nhật",
        "cn",
        "Thứ 1"
    ],
    "am": [
        "sa"
    ],
    "pm": [
        "ch"
    ],
    "year": [
        "năm"
    ],
    "month": [
        "tháng",
        "thang",
        "Thg"
    ],
    "week": [
        "tuần",
        "tuần lể"
    ],
    "day": [
        "ngày",
        "ban ngày",
        "buổi"
    ],
    "hour": [
        "giờ"
    ],
    "minute": [
        "phút",
        "chút",
        "lát",
        "nguyên bản"
    ],
    "second": [
        "giây",
        "giây đồng hồ",
        "hạng nhì"
    ],
    "relative-type": {
        "0 day ago": [
            "hôm nay"
        ],
        "0 hour ago": [
            "giờ này"
        ],
        "0 minute ago": [
            "phút này"
        ],
        "0 month ago": [
            "tháng này"
        ],
        "0 second ago": [
            "bây giờ"
        ],
        "0 week ago": [
            "tuần này"
        ],
        "0 year ago": [
            "năm nay"
        ],
        "1 day ago": [
            "hôm qua"
        ],
        "1 month ago": [
            "tháng trước"
        ],
        "1 week ago": [
            "tuần trước"
        ],
        "1 year ago": [
            "năm ngoái"
        ],
        "in 1 day": [
            "ngày mai"
        ],
        "in 1 month": [
            "tháng sau"
        ],
        "in 1 week": [
            "tuần sau"
        ],
        "in 1 year": [
            "năm sau"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) ngày trước"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) giờ trước"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) phút trước"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) tháng trước"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) giây trước"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) tuần trước"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) năm trước"
        ],
        "in \\1 day": [
            "sau (\\d+[.,]?\\d*) ngày nữa"
        ],
        "in \\1 hour": [
            "sau (\\d+[.,]?\\d*) giờ nữa"
        ],
        "in \\1 minute": [
            "sau (\\d+[.,]?\\d*) phút nữa"
        ],
        "in \\1 month": [
            "sau (\\d+[.,]?\\d*) tháng nữa"
        ],
        "in \\1 second": [
            "sau (\\d+[.,]?\\d*) giây nữa"
        ],
        "in \\1 week": [
            "sau (\\d+[.,]?\\d*) tuần nữa"
        ],
        "in \\1 year": [
            "sau (\\d+[.,]?\\d*) năm nữa"
        ]
    },
    "locale_specific": {},
    "pertain": [
        "lúc"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "cách đây",
        "trước đây",
        "trước",
        "trước"
    ],
    "in": [
        "trong"
    ],
    "simplifications": [
        {
            "(?:ngày|năm)\\s(\\d+[.,]?\\d*)": "\\1"
        }
    ],
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



import regex as re
from dateparser.utils import get_logger


class LanguageValidator:
    logger = None

    VALID_KEYS = [
        'name', 'skip', 'pertain', 'simplifications', 'no_word_spacing', 'ago', 'in',
        'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday',
        'january', 'february', 'march', 'april', 'may', 'june', 'july', 'august',
        'september', 'october', 'november', 'december', 'year', 'month', 'week', 'day',
        'hour', 'minute', 'second', 'sentence_splitter_group'
    ]

    @classmethod
    def get_logger(cls):
        if cls.logger is None:
            cls.logger = get_logger()
        return cls.logger

    @classmethod
    def validate_info(cls, language_id, info):
        result = True

        result &= cls._validate_type(language_id, info)
        if not result:
            return False

        result &= cls._validate_name(language_id, info)
        result &= cls._validate_word_spacing(language_id, info)
        result &= cls._validate_skip_list(language_id, info)
        result &= cls._validate_pertain_list(language_id, info)
        result &= cls._validate_weekdays(language_id, info)
        result &= cls._validate_months(language_id, info)
        result &= cls._validate_units(language_id, info)
        result &= cls._validate_other_words(language_id, info)
        result &= cls._validate_simplifications(language_id, info)
        result &= cls._validate_extra_keys(language_id, info)
        return result

    @classmethod
    def _validate_type(cls, language_id, info):
        result = True

        if not isinstance(info, dict):
            cls.get_logger().error(
                "Language '%(id)s' info expected to be dict, but have got %(type)s",
                {'id': language_id, 'type': type(info).__name__})
            result = False

        return result

    @classmethod
    def _validate_name(cls, language_id, info):
        result = True

        if 'name' not in info or not isinstance(info['name'], str) or not info['name']:
            cls.get_logger().error("Language '%(id)s' does not have a name", {'id': language_id})
            result = False

        return result

    @classmethod
    def _validate_word_spacing(cls, language_id, info):
        if 'no_word_spacing' not in info:
            return True  # Optional key

        result = True

        value = info['no_word_spacing']
        if value not in [True, False]:
            cls.get_logger().error(
                "Invalid 'no_word_spacing' value %(value)r for '%(id)s' language: "
                "expected boolean", {'value': value, 'id': language_id})
            result = False

        return result

    @classmethod
    def _validate_sentence_splitter_group(cls, language_id, info):
        if 'sentence_splitter_group' not in info:
            return True  # Optional key

        result = True

        group = info['sentence_splitter_group']
        if isinstance(group, int) or not group:
            if group < 1 or group > 6:
                cls.get_logger().error(
                    "Invalid 'sentence_splitter_group' number %(number)r for '%(id)s' language: "
                    "expected number from 1 to 6",
                    {'number': group, 'id': language_id}
                )
                result = False
        else:
            cls.get_logger().error(
                "Invalid 'sentence_splitter_group' for '%(id)s' language: "
                "expected int type but have got %(type)s",
                {'id': language_id, 'type': type(group).__name__})
            result = False

        return result

    @classmethod
    def _validate_skip_list(cls, language_id, info):
        if 'skip' not in info:
            return True  # Optional key

        result = True

        skip_tokens_list = info['skip']
        if isinstance(skip_tokens_list, list):
            for token in skip_tokens_list:
                if not isinstance(token, str) or not token:
                    cls.get_logger().error(
                        "Invalid 'skip' token %(token)r for '%(id)s' language: "
                        "expected not empty string",
                        {'token': token, 'id': language_id})
                    result = False
        else:
            cls.get_logger().error(
                "Invalid 'skip' list for '%(id)s' language: "
                "expected list type but have got %(type)s",
                {'id': language_id, 'type': type(skip_tokens_list).__name__})
            result = False

        return result

    @classmethod
    def _validate_pertain_list(cls, language_id, info):
        if 'pertain' not in info:
            return True  # Optional key

        result = True

        pertain_tokens_list = info['skip']
        if isinstance(pertain_tokens_list, list):
            for token in pertain_tokens_list:
                if not isinstance(token, str) or not token:
                    cls.get_logger().error(
                        "Invalid 'pertain' token %(token)r for '%(id)s' language: "
                        "expected not empty string",
                        {'token': token, 'id': language_id})
                    result = False
        else:
            cls.get_logger().error(
                "Invalid 'pertain' list for '%(id)s' language: "
                "expected list type but have got %(type)s",
                {'id': language_id, 'type': type(pertain_tokens_list).__name__})
            result = False

        return result

    @classmethod
    def _validate_weekdays(cls, language_id, info):
        result = True

        for weekday in 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday':
            if weekday not in info or not info[weekday]:
                cls.get_logger().error(
                    "No translations for '%(weekday)s' provided for '%(id)s' language",
                    {'weekday': weekday, 'id': language_id})
                result = False
                continue

            translations_list = info[weekday]
            if isinstance(translations_list, list):
                for token in translations_list:
                    if not isinstance(token, str) or not token:
                        cls.get_logger().error(
                            "Invalid '%(weekday)s' translation %(token)r for '%(id)s' language: "
                            "expected not empty string",
                            {'weekday': weekday, 'token': token, 'id': language_id})
                        result = False
            else:
                cls.get_logger().error(
                    "Invalid '%(weekday)s' translations list for '%(id)s' language: "
                    "expected list type but have got %(type)s",
                    {'weekday': weekday,
                     'id': language_id,
                     'type': type(translations_list).__name__})
                result = False

        return result

    @classmethod
    def _validate_months(cls, language_id, info):
        result = True

        for month in ('january', 'february', 'march', 'april', 'may', 'june', 'july',
                      'august', 'september', 'october', 'november', 'december'):
            if month not in info or not info[month]:
                cls.get_logger().error(
                    "No translations for '%(month)s' provided for '%(id)s' language",
                    {'month': month, 'id': language_id})
                result = False
                continue

            translations_list = info[month]
            if isinstance(translations_list, list):
                for token in translations_list:
                    if not isinstance(token, str) or not token:
                        cls.get_logger().error(
                            "Invalid '%(month)s' translation %(token)r for '%(id)s' language: "
                            "expected not empty string",
                            {'month': month, 'token': token, 'id': language_id})
                        result = False
            else:
                cls.get_logger().error(
                    "Invalid '%(month)s' translations list for '%(id)s' language: "
                    "expected list type but have got %(type)s",
                    {'month': month, 'id': language_id, 'type': type(translations_list).__name__})
                result = False

        return result

    @classmethod
    def _validate_units(cls, language_id, info):
        result = True

        for unit in 'year', 'month', 'week', 'day', 'hour', 'minute', 'second':
            if unit not in info or not info[unit]:
                cls.get_logger().error(
                    "No translations for '%(unit)s' provided for '%(id)s' language",
                    {'unit': unit, 'id': language_id})
                result = False
                continue

            translations_list = info[unit]
            if isinstance(translations_list, list):
                for token in translations_list:
                    if not isinstance(token, str) or not token:
                        cls.get_logger().error(
                            "Invalid '%(unit)s' translation %(token)r for '%(id)s' language: "
                            "expected not empty string",
                            {'unit': unit, 'token': token, 'id': language_id})
                        result = False
            else:
                cls.get_logger().error(
                    "Invalid '%(unit)s' translations list for '%(id)s' language: "
                    "expected list type but have got %(type)s",
                    {'unit': unit, 'id': language_id, 'type': type(translations_list).__name__})
                result = False

        return result

    @classmethod
    def _validate_other_words(cls, language_id, info):
        result = True

        for word in 'ago', :
            if word not in info or not info[word]:
                cls.get_logger().error(
                    "No translations for '%(word)s' provided for '%(id)s' language",
                    {'word': word, 'id': language_id})
                result = False
                continue

            translations_list = info[word]
            if isinstance(translations_list, list):
                for token in translations_list:
                    if not isinstance(token, str) or not token:
                        cls.get_logger().error(
                            "Invalid '%(word)s' translation %(token)r for '%(id)s' language: "
                            "expected not empty string",
                            {'word': word, 'token': token, 'id': language_id})
                        result = False
            else:
                cls.get_logger().error(
                    "Invalid '%(word)s' translations list for '%(id)s' language: "
                    "expected list type but have got %(type)s",
                    {'word': word, 'id': language_id, 'type': type(translations_list).__name__})
                result = False

        return result

    @classmethod
    def _validate_simplifications(cls, language_id, info):
        if 'simplifications' not in info:
            return True  # Optional key

        result = True

        simplifications_list = info['simplifications']
        if isinstance(simplifications_list, list):
            for simplification in simplifications_list:
                if not isinstance(simplification, dict) or len(simplification) != 1:
                    cls.get_logger().error(
                        "Invalid simplification %(simplification)r for '%(id)s' language: "
                        "eash simplification suppose to be one-to-one mapping",
                        {'simplification': simplification, 'id': language_id})
                    result = False
                    continue

                key, value = list(simplification.items())[0]
                if not isinstance(key, str) or not isinstance(value, (str, int)):
                    cls.get_logger().error(
                        "Invalid simplification %(simplification)r for '%(id)s' language: "
                        "each simplification suppose to be string-to-string-or-int mapping",
                        {'simplification': simplification, 'id': language_id})
                    result = False
                    continue

                compiled_key = re.compile(key)
                value = str(value)
                replacements = re.findall(r'\\(\d+)', value)
                replacements.extend(re.findall(r'\\g<(.+?)>', value))

                groups = []
                for group in replacements:
                    if group.isdigit():
                        groups.append(int(group))
                    elif group in compiled_key.groupindex:
                        groups.append(compiled_key.groupindex[group])
                    else:
                        cls.get_logger().error(
                            "Invalid simplification %(simplification)r for '%(id)s' language: "
                            "unknown group %(group)s",
                            {'simplification': simplification,
                             'id': language_id,
                             'group': group})
                        result = False

                used_groups = set(map(int, groups))
                expected_groups = set(range(0, compiled_key.groups + 1))
                extra_groups = used_groups - expected_groups
                not_used_groups = expected_groups - used_groups
                not_used_groups -= {0}  # Entire substring is not required to be used

                if extra_groups:
                    cls.get_logger().error(
                        "Invalid simplification %(simplification)r for '%(id)s' language: "
                        "unknown groups %(groups)s",
                        {'simplification': simplification,
                         'id': language_id,
                         'groups': ", ".join(map(str, sorted(extra_groups)))})
                    result = False

                if not_used_groups:
                    cls.get_logger().error(
                        "Invalid simplification %(simplification)r for '%(id)s' language: "
                        "groups %(groups)s were not used",
                        {'simplification': simplification,
                         'id': language_id,
                         'groups': ", ".join(map(str, sorted(not_used_groups)))})
                    result = False
        else:
            cls.get_logger().error(
                "Invalid 'simplifications' list for '%(id)s' language: "
                "expected list type but have got %(type)s",
                {'id': language_id, 'type': type(simplifications_list).__name__})
            result = False

        return result

    @classmethod
    def _validate_extra_keys(cls, language_id, info):
        result = True

        extra_keys = set(info.keys()) - set(cls.VALID_KEYS)
        if extra_keys:
            cls.get_logger().error(
                "Extra keys found for '%(id)s' language: %(keys)s",
                {'id': language_id, 'keys': ", ".join(map(repr, extra_keys))})
            result = False

        return result



info = {
    "name": "kln",
    "date_order": "DMY",
    "january": [
        "mul",
        "mulgul"
    ],
    "february": [
        "ng'atyaato",
        "ngat"
    ],
    "march": [
        "kiptaamo",
        "taa"
    ],
    "april": [
        "iwo",
        "iwootkuut"
    ],
    "may": [
        "mam",
        "mamuut"
    ],
    "june": [
        "paa",
        "paagi"
    ],
    "july": [
        "ng'eiyeet",
        "nge"
    ],
    "august": [
        "roo",
        "rooptui"
    ],
    "september": [
        "bur",
        "bureet"
    ],
    "october": [
        "epe",
        "epeeso"
    ],
    "november": [
        "kipsuunde ne taai",
        "kpt"
    ],
    "december": [
        "kipsuunde nebo aeng'",
        "kpa"
    ],
    "monday": [
        "kot",
        "kotaai"
    ],
    "tuesday": [
        "koaeng'",
        "koo"
    ],
    "wednesday": [
        "kos",
        "kosomok"
    ],
    "thursday": [
        "koa",
        "koang'wan"
    ],
    "friday": [
        "kom",
        "komuut"
    ],
    "saturday": [
        "kol",
        "kolo"
    ],
    "sunday": [
        "kotisap",
        "kts"
    ],
    "am": [
        "karoon",
        "krn"
    ],
    "pm": [
        "koosk",
        "kooskoliny"
    ],
    "year": [
        "kenyit"
    ],
    "month": [
        "arawet"
    ],
    "week": [
        "wikit"
    ],
    "day": [
        "betut"
    ],
    "hour": [
        "sait"
    ],
    "minute": [
        "minitit"
    ],
    "second": [
        "sekondit"
    ],
    "relative-type": {
        "0 day ago": [
            "raini"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "amut"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "mutai"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "cy",
    "date_order": "DMY",
    "january": [
        "ion",
        "ionawr"
    ],
    "february": [
        "chw",
        "chwef",
        "chwefror"
    ],
    "march": [
        "maw",
        "mawrth"
    ],
    "april": [
        "ebr",
        "ebrill"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "meh",
        "mehefin"
    ],
    "july": [
        "gor",
        "gorff",
        "gorffennaf"
    ],
    "august": [
        "awst"
    ],
    "september": [
        "medi"
    ],
    "october": [
        "hyd",
        "hydref"
    ],
    "november": [
        "tach",
        "tachwedd"
    ],
    "december": [
        "rhag",
        "rhagfyr"
    ],
    "monday": [
        "dydd llun",
        "llun"
    ],
    "tuesday": [
        "dydd mawrth",
        "maw"
    ],
    "wednesday": [
        "dydd mercher",
        "mer"
    ],
    "thursday": [
        "dydd iau",
        "iau"
    ],
    "friday": [
        "dydd gwener",
        "gwe",
        "gwen"
    ],
    "saturday": [
        "dydd sadwrn",
        "sad"
    ],
    "sunday": [
        "dydd sul",
        "sul"
    ],
    "am": [
        "yb"
    ],
    "pm": [
        "yh"
    ],
    "year": [
        "bl",
        "blwyddyn"
    ],
    "month": [
        "mis"
    ],
    "week": [
        "wythnos"
    ],
    "day": [
        "dydd"
    ],
    "hour": [
        "awr"
    ],
    "minute": [
        "mun",
        "munud"
    ],
    "second": [
        "eiliad"
    ],
    "relative-type": {
        "0 day ago": [
            "heddiw"
        ],
        "0 hour ago": [
            "yr awr hon"
        ],
        "0 minute ago": [
            "y funud hon"
        ],
        "0 month ago": [
            "y mis hwn"
        ],
        "0 second ago": [
            "nawr"
        ],
        "0 week ago": [
            "yr wythnos hon"
        ],
        "0 year ago": [
            "eleni"
        ],
        "1 day ago": [
            "ddoe"
        ],
        "1 month ago": [
            "mis diwethaf"
        ],
        "1 week ago": [
            "wythnos ddiwethaf"
        ],
        "1 year ago": [
            "llynedd"
        ],
        "in 1 day": [
            "yfory"
        ],
        "in 1 month": [
            "mis nesaf"
        ],
        "in 1 week": [
            "wythnos nesaf"
        ],
        "in 1 year": [
            "blwyddyn nesaf"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) diwrnod yn ôl"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) awr yn ôl"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) mun yn ôl",
            "(\\d+[.,]?\\d*) munud yn ôl"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) mis yn ôl"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) eiliad yn ôl"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) wythnos yn ôl"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) o flynyddoedd yn ôl"
        ],
        "in \\1 day": [
            "ymhen (\\d+[.,]?\\d*) diwrnod"
        ],
        "in \\1 hour": [
            "ymhen (\\d+[.,]?\\d*) awr"
        ],
        "in \\1 minute": [
            "ymhen (\\d+[.,]?\\d*) mun",
            "ymhen (\\d+[.,]?\\d*) munud"
        ],
        "in \\1 month": [
            "ymhen (\\d+[.,]?\\d*) mis"
        ],
        "in \\1 second": [
            "ymhen (\\d+[.,]?\\d*) eiliad"
        ],
        "in \\1 week": [
            "ymhen (\\d+[.,]?\\d*) wythnos"
        ],
        "in \\1 year": [
            "ymhen (\\d+[.,]?\\d*) mlynedd"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "el",
    "date_order": "DMY",
    "january": [
        "ιαν",
        "ιανουάριος",
        "ιανουαρίου"
    ],
    "february": [
        "φεβ",
        "φεβρουάριος",
        "φεβρουαρίου"
    ],
    "march": [
        "μάρ",
        "μάρτιος",
        "μαρ",
        "μαρτίου"
    ],
    "april": [
        "απρ",
        "απρίλιος",
        "απριλίου"
    ],
    "may": [
        "μάι",
        "μάιος",
        "μαΐ",
        "μαΐου"
    ],
    "june": [
        "ιουν",
        "ιουνίου",
        "ιούν",
        "ιούνιος"
    ],
    "july": [
        "ιουλ",
        "ιουλίου",
        "ιούλ",
        "ιούλιος"
    ],
    "august": [
        "αυγ",
        "αυγούστου",
        "αύγ",
        "αύγουστος"
    ],
    "september": [
        "σεπ",
        "σεπτέμβριος",
        "σεπτεμβρίου"
    ],
    "october": [
        "οκτ",
        "οκτωβρίου",
        "οκτώβριος"
    ],
    "november": [
        "νοέ",
        "νοέμβριος",
        "νοε",
        "νοεμβρίου"
    ],
    "december": [
        "δεκ",
        "δεκέμβριος",
        "δεκεμβρίου"
    ],
    "monday": [
        "δευ",
        "δευτέρα"
    ],
    "tuesday": [
        "τρί",
        "τρίτη"
    ],
    "wednesday": [
        "τετ",
        "τετάρτη"
    ],
    "thursday": [
        "πέμ",
        "πέμπτη"
    ],
    "friday": [
        "παρ",
        "παρασκευή"
    ],
    "saturday": [
        "σάβ",
        "σάββατο"
    ],
    "sunday": [
        "κυρ",
        "κυριακή"
    ],
    "am": [
        "πμ"
    ],
    "pm": [
        "μμ"
    ],
    "year": [
        "έτ",
        "έτος"
    ],
    "month": [
        "μήν",
        "μήνας"
    ],
    "week": [
        "εβδ",
        "εβδομάδα"
    ],
    "day": [
        "ημέρα"
    ],
    "hour": [
        "ώ",
        "ώρ",
        "ώρα"
    ],
    "minute": [
        "λ",
        "λεπ",
        "λεπτό"
    ],
    "second": [
        "δ",
        "δευτ",
        "δευτερόλεπτο"
    ],
    "relative-type": {
        "0 day ago": [
            "σήμερα"
        ],
        "0 hour ago": [
            "αυτήν την ώρα"
        ],
        "0 minute ago": [
            "αυτό το λεπτό"
        ],
        "0 month ago": [
            "τρέχων μήνας"
        ],
        "0 second ago": [
            "τώρα"
        ],
        "0 week ago": [
            "αυτήν την εβδομάδα"
        ],
        "0 year ago": [
            "φέτος"
        ],
        "1 day ago": [
            "χθες"
        ],
        "1 month ago": [
            "προηγούμενος μήνας"
        ],
        "1 week ago": [
            "προηγούμενη εβδομάδα"
        ],
        "1 year ago": [
            "πέρσι"
        ],
        "in 1 day": [
            "αύριο"
        ],
        "in 1 month": [
            "επόμενος μήνας"
        ],
        "in 1 week": [
            "επόμενη εβδομάδα"
        ],
        "in 1 year": [
            "επόμενο έτος"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) ημ πριν",
            "πριν από (\\d+[.,]?\\d*) ημέρα",
            "πριν από (\\d+[.,]?\\d*) ημέρες"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) ώ πριν",
            "πριν από (\\d+[.,]?\\d*) ώρ",
            "πριν από (\\d+[.,]?\\d*) ώρα",
            "πριν από (\\d+[.,]?\\d*) ώρες"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) λ πριν",
            "πριν από (\\d+[.,]?\\d*) λεπ",
            "πριν από (\\d+[.,]?\\d*) λεπτά",
            "πριν από (\\d+[.,]?\\d*) λεπτό"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) μ πριν",
            "πριν από (\\d+[.,]?\\d*) μήνα",
            "πριν από (\\d+[.,]?\\d*) μήνες"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) δ πριν",
            "πριν από (\\d+[.,]?\\d*) δευτ",
            "πριν από (\\d+[.,]?\\d*) δευτερόλεπτα",
            "πριν από (\\d+[.,]?\\d*) δευτερόλεπτο"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) εβδ πριν",
            "πριν από (\\d+[.,]?\\d*) εβδ",
            "πριν από (\\d+[.,]?\\d*) εβδομάδα",
            "πριν από (\\d+[.,]?\\d*) εβδομάδες"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) έτη πριν",
            "(\\d+[.,]?\\d*) έτος πριν",
            "πριν από (\\d+[.,]?\\d*) έτη",
            "πριν από (\\d+[.,]?\\d*) έτος"
        ],
        "in \\1 day": [
            "σε (\\d+[.,]?\\d*) ημ",
            "σε (\\d+[.,]?\\d*) ημέρα",
            "σε (\\d+[.,]?\\d*) ημέρες"
        ],
        "in \\1 hour": [
            "σε (\\d+[.,]?\\d*) ώ",
            "σε (\\d+[.,]?\\d*) ώρ",
            "σε (\\d+[.,]?\\d*) ώρα",
            "σε (\\d+[.,]?\\d*) ώρες"
        ],
        "in \\1 minute": [
            "σε (\\d+[.,]?\\d*) λ",
            "σε (\\d+[.,]?\\d*) λεπ",
            "σε (\\d+[.,]?\\d*) λεπτά",
            "σε (\\d+[.,]?\\d*) λεπτό"
        ],
        "in \\1 month": [
            "σε (\\d+[.,]?\\d*) μ",
            "σε (\\d+[.,]?\\d*) μήνα",
            "σε (\\d+[.,]?\\d*) μήνες"
        ],
        "in \\1 second": [
            "σε (\\d+[.,]?\\d*) δ",
            "σε (\\d+[.,]?\\d*) δευτ",
            "σε (\\d+[.,]?\\d*) δευτερόλεπτα",
            "σε (\\d+[.,]?\\d*) δευτερόλεπτο"
        ],
        "in \\1 week": [
            "σε (\\d+[.,]?\\d*) εβδ",
            "σε (\\d+[.,]?\\d*) εβδομάδα",
            "σε (\\d+[.,]?\\d*) εβδομάδες"
        ],
        "in \\1 year": [
            "σε (\\d+[.,]?\\d*) έτη",
            "σε (\\d+[.,]?\\d*) έτος"
        ]
    },
    "locale_specific": {
        "el-CY": {
            "name": "el-CY"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



info = {
    "name": "lu",
    "date_order": "DMY",
    "january": [
        "cio",
        "ciongo"
    ],
    "february": [
        "lui",
        "lùishi"
    ],
    "march": [
        "lus",
        "lusòlo"
    ],
    "april": [
        "muu",
        "mùuyà"
    ],
    "may": [
        "lum",
        "lumùngùlù"
    ],
    "june": [
        "luf",
        "lufuimi"
    ],
    "july": [
        "kab",
        "kabàlàshìpù"
    ],
    "august": [
        "lush",
        "lùshìkà"
    ],
    "september": [
        "lut",
        "lutongolo"
    ],
    "october": [
        "lun",
        "lungùdi"
    ],
    "november": [
        "kas",
        "kaswèkèsè"
    ],
    "december": [
        "cis",
        "ciswà"
    ],
    "monday": [
        "nko",
        "nkodya"
    ],
    "tuesday": [
        "ndy",
        "ndàayà"
    ],
    "wednesday": [
        "ndangù",
        "ndg"
    ],
    "thursday": [
        "njw",
        "njòwa"
    ],
    "friday": [
        "ngv",
        "ngòvya"
    ],
    "saturday": [
        "lub",
        "lubingu"
    ],
    "sunday": [
        "lum",
        "lumingu"
    ],
    "am": [
        "dinda"
    ],
    "pm": [
        "dilolo"
    ],
    "year": [
        "tshidimu"
    ],
    "month": [
        "ngondo"
    ],
    "week": [
        "lubingu"
    ],
    "day": [
        "dituku"
    ],
    "hour": [
        "diba"
    ],
    "minute": [
        "kasunsu"
    ],
    "second": [
        "kasunsukusu"
    ],
    "relative-type": {
        "0 day ago": [
            "lelu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "makelela"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "malaba"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
